========================
``psyclone.psyad.tl2ad``
========================

.. automodule:: psyclone.psyad.tl2ad

   .. contents::
      :local:

.. currentmodule:: psyclone.psyad.tl2ad


Functions
=========

- :py:func:`generate_adjoint_str`:
  Takes an LFRic tangent-linear kernel encoded as a string as input

- :py:func:`generate_adjoint`:
  Takes an LFRic tangent-linear kernel represented in language-level PSyIR

- :py:func:`generate_adjoint_test`:
  Creates the PSyIR of a test harness for the supplied TL and adjoint


.. autofunction:: generate_adjoint_str

.. autofunction:: generate_adjoint

.. autofunction:: generate_adjoint_test
